// src/internals/context.ts
import { getContext, setContext } from "svelte";
var trpcContextKey = Symbol("trpcContext");
function setContextClient(client) {
  setContext(trpcContextKey, client);
}
function getContextClient() {
  return getContext(trpcContextKey);
}

// src/shared/utils.ts
import {
  useQueryClient
} from "@tanstack/svelte-query";
import { BROWSER } from "esm-env";

// src/internals/getArrayQueryKey.ts
function getArrayQueryKey(path, input, type) {
  const hasInput = typeof input !== "undefined";
  const hasType = type && type !== "any";
  if (!hasInput && !hasType)
    return path.length ? [path] : [];
  const inputAndType = {};
  if (hasInput)
    inputAndType.input = input;
  if (hasType)
    inputAndType.type = type;
  return [path, inputAndType];
}

// src/utils/splitUserOptions.ts
function splitUserOptions(options) {
  if (options === void 0) {
    return [];
  }
  const trpcOptions = {
    context: options.context,
    signal: options.signal
  };
  delete options.context;
  delete options.signal;
  return [trpcOptions, options];
}

// src/shared/utils.ts
var queryTypes = {
  invalidate: "any",
  prefetch: "query",
  prefetchInfinite: "infinite",
  fetch: "query",
  fetchInfinite: "infinite",
  refetch: "any",
  cancel: "any",
  reset: "any",
  setData: "query",
  setInfiniteData: "infinite",
  getData: "query",
  getInfiniteData: "infinite"
};
function callUtilMethod(trpc, client, path, method, args) {
  if (!BROWSER) {
    client = useQueryClient();
  }
  const queryType = queryTypes[method];
  const queryKey = getArrayQueryKey(path, args[0], queryType);
  switch (method) {
    case "prefetch":
    case "fetch":
    case "prefetchInfinite":
    case "fetchInfinite": {
      const joinedPath = path.join(".");
      const options = args[1];
      const [trpcOptions, tanstackQueryOptions] = splitUserOptions(options);
      const queryFn = queryType === "query" ? () => trpc.query(joinedPath, args[0], trpcOptions) : (context) => {
        const input = { ...args[0], cursor: context.pageParam };
        return trpc.query(joinedPath, input, trpcOptions);
      };
      return client[method + "Query"]({
        ...tanstackQueryOptions,
        queryKey,
        queryFn
      });
    }
    case "invalidate":
      return client.invalidateQueries(queryKey, args[1], args[2]);
    case "refetch":
      return client.refetchQueries(
        getArrayQueryKey(path, args[0], "query"),
        args[1],
        args[2]
      );
    case "cancel":
      return client.cancelQueries(queryKey, args[1], args[2]);
    case "reset":
      return client.resetQueries(queryKey, args[1], args[2]);
    case "setData":
    case "setInfiniteData":
      return client.setQueryData(queryKey, args[1], args[2]);
    case "getData":
    case "getInfiniteData":
      return client.getQueryData(queryKey, args[1]);
    default:
      throw new TypeError(`trpc.${path}.${method} is not a function`);
  }
}

export {
  getArrayQueryKey,
  setContextClient,
  getContextClient,
  splitUserOptions,
  callUtilMethod
};
