"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/shared/index.ts
var shared_exports = {};
__export(shared_exports, {
  callUtilMethod: () => callUtilMethod,
  getContextClient: () => getContextClient,
  setContextClient: () => setContextClient
});
module.exports = __toCommonJS(shared_exports);

// src/internals/context.ts
var import_svelte = require("svelte");
var trpcContextKey = Symbol("trpcContext");
function setContextClient(client) {
  (0, import_svelte.setContext)(trpcContextKey, client);
}
function getContextClient() {
  return (0, import_svelte.getContext)(trpcContextKey);
}

// src/shared/utils.ts
var import_svelte_query = require("@tanstack/svelte-query");
var import_esm_env = require("esm-env");

// src/internals/getArrayQueryKey.ts
function getArrayQueryKey(path, input, type) {
  const hasInput = typeof input !== "undefined";
  const hasType = type && type !== "any";
  if (!hasInput && !hasType)
    return path.length ? [path] : [];
  const inputAndType = {};
  if (hasInput)
    inputAndType.input = input;
  if (hasType)
    inputAndType.type = type;
  return [path, inputAndType];
}

// src/utils/splitUserOptions.ts
function splitUserOptions(options) {
  if (options === void 0) {
    return [];
  }
  const trpcOptions = {
    context: options.context,
    signal: options.signal
  };
  delete options.context;
  delete options.signal;
  return [trpcOptions, options];
}

// src/shared/utils.ts
var queryTypes = {
  invalidate: "any",
  prefetch: "query",
  prefetchInfinite: "infinite",
  fetch: "query",
  fetchInfinite: "infinite",
  refetch: "any",
  cancel: "any",
  reset: "any",
  setData: "query",
  setInfiniteData: "infinite",
  getData: "query",
  getInfiniteData: "infinite"
};
function callUtilMethod(trpc, client, path, method, args) {
  if (!import_esm_env.BROWSER) {
    client = (0, import_svelte_query.useQueryClient)();
  }
  const queryType = queryTypes[method];
  const queryKey = getArrayQueryKey(path, args[0], queryType);
  switch (method) {
    case "prefetch":
    case "fetch":
    case "prefetchInfinite":
    case "fetchInfinite": {
      const joinedPath = path.join(".");
      const options = args[1];
      const [trpcOptions, tanstackQueryOptions] = splitUserOptions(options);
      const queryFn = queryType === "query" ? () => trpc.query(joinedPath, args[0], trpcOptions) : (context) => {
        const input = { ...args[0], cursor: context.pageParam };
        return trpc.query(joinedPath, input, trpcOptions);
      };
      return client[method + "Query"]({
        ...tanstackQueryOptions,
        queryKey,
        queryFn
      });
    }
    case "invalidate":
      return client.invalidateQueries(queryKey, args[1], args[2]);
    case "refetch":
      return client.refetchQueries(
        getArrayQueryKey(path, args[0], "query"),
        args[1],
        args[2]
      );
    case "cancel":
      return client.cancelQueries(queryKey, args[1], args[2]);
    case "reset":
      return client.resetQueries(queryKey, args[1], args[2]);
    case "setData":
    case "setInfiniteData":
      return client.setQueryData(queryKey, args[1], args[2]);
    case "getData":
    case "getInfiniteData":
      return client.getQueryData(queryKey, args[1]);
    default:
      throw new TypeError(`trpc.${path}.${method} is not a function`);
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  callUtilMethod,
  getContextClient,
  setContextClient
});
